@@ -607,7 +607,6 @@ class CameraDeviceCapability(str, Enum):
     Battery = "Battery"
 
     PTZ = "PTZ"
-    PTZMove = "PTZMove"
     PTZHome = "PTZHome"
     PTZPresets = "PTZPresets"
     PTZZoom = "PTZZoom"
@@ -905,6 +904,7 @@ class CameraDevice(Protocol):
     def get_capabilities(self) -> list[CameraDeviceCapability]: ...
     def has_capability(self, capability: CameraDeviceCapability) -> bool: ...
     def add_capabilities(self, capabilities: list[CameraDeviceCapability]) -> None: ...
+    def remove_capabilities(self, capabilities: list[CameraDeviceCapability]) -> None: ...
 
 
 CameraSelectedCallback = Union[
